==> ejc-ztpccom-impl-3.0.0-20230717.143318-54-sources.jar: com/ejianc/business/pub/bean/BillCodeRuleAttrEntity.java <==
package com.ejianc.business.pub.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 取号编码规则子元素
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ztpccom_billcode_rule_attr")
public class BillCodeRuleAttrEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="rule_id")
    private Long ruleId; // 主表id
    @TableField(value="elem_order")
    private Integer elemOrder; // 序号
    @TableField(value="rule_elem")
    private Long ruleElem; // 元素
    @TableField(value="rule_elem_code")
    private String ruleElemCode; // 元素字段code
    @TableField(value="rule_elem_type")
    private String ruleElemType; // 元素类型
    @TableField(value="elem_value")
    private String elemValue; // 属性值
    @TableField(value="start_num")
    private Integer startNum; // 流水起始号
    @TableField(value="end_num")
    private Integer endNum; // 流水结束号
    @TableField(value="elem_length")
    private Integer elemLength; // 长度

    public Long getRuleId() {
        return ruleId;
    }

    public void setRuleId(Long ruleId) {
        this.ruleId = ruleId;
    }

    public Integer getElemOrder() {
        return elemOrder;
    }

    public void setElemOrder(Integer elemOrder) {
        this.elemOrder = elemOrder;
    }
    public Long getRuleElem() {
        return ruleElem;
    }

    public void setRuleElem(Long ruleElem) {
        this.ruleElem = ruleElem;
    }
    public String getRuleElemType() {
        return ruleElemType;
    }

    public void setRuleElemType(String ruleElemType) {
        this.ruleElemType = ruleElemType;
    }
    public String getElemValue() {
        return elemValue;
    }

    public void setElemValue(String elemValue) {
        this.elemValue = elemValue;
    }
    public Integer getStartNum() {
        return startNum;
    }

    public void setStartNum(Integer startNum) {
        this.startNum = startNum;
    }
    public Integer getEndNum() {
        return endNum;
    }

    public void setEndNum(Integer endNum) {
        this.endNum = endNum;
    }
    public Integer getElemLength() {
        return elemLength;
    }

    public void setElemLength(Integer elemLength) {
        this.elemLength = elemLength;
    }

    public String getRuleElemCode() {
        return ruleElemCode;
    }

    public void setRuleElemCode(String ruleElemCode) {
        this.ruleElemCode = ruleElemCode;
    }
}

==> ejc-ztpccom-impl-3.0.0-20231018.124416-88-sources.jar: com/ejianc/business/pub/bean/BillCodeRuleAttrEntity.java <==
package com.ejianc.business.pub.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 取号编码规则子元素
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ztpccom_billcode_rule_attr")
public class BillCodeRuleAttrEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="rule_id")
    private Long ruleId; // 主表id
    @TableField(value="elem_order")
    private Integer elemOrder; // 序号
    @TableField(value="rule_elem")
    private Long ruleElem; // 元素
    @TableField(value="rule_elem_code")
    private String ruleElemCode; // 元素字段code
    @TableField(value="rule_elem_type")
    private String ruleElemType; // 元素类型
    @TableField(value="elem_value")
    private String elemValue; // 属性值
    @TableField(value="start_num")
    private Integer startNum; // 流水起始号
    @TableField(value="end_num")
    private Integer endNum; // 流水结束号
    @TableField(value="elem_length")
    private Integer elemLength; // 长度
    @TableField(value="memo")
    private String memo; // 备注

    public Long getRuleId() {
        return ruleId;
    }

    public void setRuleId(Long ruleId) {
        this.ruleId = ruleId;
    }

    public Integer getElemOrder() {
        return elemOrder;
    }

    public void setElemOrder(Integer elemOrder) {
        this.elemOrder = elemOrder;
    }
    public Long getRuleElem() {
        return ruleElem;
    }

    public void setRuleElem(Long ruleElem) {
        this.ruleElem = ruleElem;
    }
    public String getRuleElemType() {
        return ruleElemType;
    }

    public void setRuleElemType(String ruleElemType) {
        this.ruleElemType = ruleElemType;
    }
    public String getElemValue() {
        return elemValue;
    }

    public void setElemValue(String elemValue) {
        this.elemValue = elemValue;
    }
    public Integer getStartNum() {
        return startNum;
    }

    public void setStartNum(Integer startNum) {
        this.startNum = startNum;
    }
    public Integer getEndNum() {
        return endNum;
    }

    public void setEndNum(Integer endNum) {
        this.endNum = endNum;
    }
    public Integer getElemLength() {
        return elemLength;
    }

    public void setElemLength(Integer elemLength) {
        this.elemLength = elemLength;
    }

    public String getRuleElemCode() {
        return ruleElemCode;
    }

    public void setRuleElemCode(String ruleElemCode) {
        this.ruleElemCode = ruleElemCode;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
